@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: wordlist.cpp 1178876 2010-09-24 07:47:31Z mlaurent $
+// $Id: wordlist.cpp 1229852 2011-04-30 13:22:11Z mlaurent $
 
 #include "wordlist.h"
 
@@ -111,7 +111,7 @@ WordMap XMLParser::getList() {
 /***************************************************************************/
 
 KProgressDialog *progressDialog() {
-   KProgressDialog *pdlg = new KProgressDialog(0,  i18n("Creating Word List"), i18n("Parsing the KDE documentation..."), false);
+   KProgressDialog *pdlg = new KProgressDialog(0,  i18n("Creating Word List"), i18n("Parsing the KDE documentation..."), 0);
    pdlg->setAllowCancel (false);
    pdlg->showCancelButton (false);
    pdlg->setAutoReset(false);
